@@ -41,12 +41,8 @@ class PygameGIF:
         """
         self.filepath = filepath
         
-        self.orig_gif = Image.open(filepath)
         self.gif = Image.open(filepath)
 
-        if self.gif.n_frames == 1:
-            print(f"Warning: The image file given, {filepath}, is only 1 frame, it will still run as normal but it is prefered to use an animated image file in order to fully utilize this module")
-
         self.frames = []
         for frame in range(self.gif.n_frames):
             self.gif.seek(frame)
@@ -380,6 +376,22 @@ class PygameGIF:
             self.frame_time = time.time()-(time.time()-self.paused_time)
         self.paused = False
 
+    def reset(self) -> None:
+        self.frames = []
+        for frame in range(self.gif.n_frames):
+            self.gif.seek(frame)
+            if frame == 0:
+                if "duration" in self.gif.info:
+                    self.frames.append((pygame.image.load(self.filepath), self.gif.info["duration"]*.001))
+                else:
+                    self.frames.append((pygame.image.load(self.filepath), 1))
+            else:
+                self.frames.append((pygame.image.fromstring(self.gif.tobytes(), self.gif.size, self.gif.mode), self.gif.info["duration"]*.001))
+        self.frame = 0
+        self.frame_time = 0
+        self.paused_time = 0
+        self.paused = False
+
 def load(filepath: _FileArg) -> PygameGIF:
     """
     Loads the .gif file
